# Analysis scripts for downloading data and storing in BIDS format
**Carolyn McNabb**</br>
Last updated: September 2024


## Downloading MRI data from XNAT
First, you'll need to download the MRI data from XNAT. 

## DICOM to dicomBIDS conversion
Once data are downloaded, you can convert the DICOM files to NifTI format and arrange these according to the Brain Imaging Data Structure ([BIDS](https://bids-specification.readthedocs.io/en/stable/)). 

#### Initial environment setup
To use dcm2bids, you need to be in a python environment. First you'll need to set this up and then you can download dcm2bids.


2.1. Set up environment for dcm2bids 
```
gedit environment.yml 
```
Paste in the following:
```
name: dcm2bids
channels:
    - conda-forge
dependencies:
    - dcm2niix
    - dcm2bids
    - pip
```


Create conda environment and activate:
```
conda env create -f environment.yml --prefix ~/dcm2bids_env

source activate ~/dcm2bids_env

cd /cubric/scratch/sapcm15/BioBank_forCarolyn/sourcedata
```


2.2. Install dcm2bids
In terminal, type:
```
pip install dcm2bids
```
#### If environment has already been setup

2.2. activate environment
```
source activate ~/dcm2bids_env

cd /cubric/scratch/sapcm15/BioBank_forCarolyn/sourcedata
```


2.3. Convert raw data to BIDS format with dcm2bids
First, test that dcm2bids is working by typing
```
dcm2bids --help
```
Use the dcm2bids helper function to look at your json files (associated with each of your nifti files - these will be in the tmp_dcm2bids folder).
```
dcm2bids_helper -d /cubric/scratch/sapcm15/BioBank_forCarolyn/scans
```

### Run dcm2bids 
To run dcm2bids, you need to have a configuration file set up. For the SW2 project, this is stored in `~/gitlab/UKBiobank_CUBRIC/DownloadData/dcm2bids_config.SW2.json`

You'll also need a subject list of all the subjects you want to convert from DICOM to NifTI. This should be stored in the brainandgenomicshub gitlab folder and called `subject_list.txt`. 

Now, open `0.1_dcm2bids_SLURM.sh` and update the `#SBATCH --array=1-1` line to include all the subjects in your list that you want to convert, e.g. `#SBATCH --array=3-15`. You'll also need to update the paths in `batch_dcm2bids` to match the paths where you've downloaded the data from XNAT and the path where you keep this gitlab repository.

You should now be ready to run dcm2bids. In the linux terminal, type:
```
sbatch 0.1_dcm2bids_SLURM.sh
```
This will send the command to the cluster and each subject will get it's own job id. You can check the progress of the jobs by typing:
```
squeue -u <youruserid>
```
You can cancel all the jobs you just sent by typing:
```
scancel -u <youruserid>
```
You can cancel individual jobs too, by typing:
```
scancel <jobid>
```

Once the job has finished, you can check whether there were any errors by looking in the reports folder you specified in `0.1_dcm2bids_SLURM.sh`. The job will create two files, one ending `.err` and one ending `.out`. You will need to check both of them to make sure the job ran okay.