#!/bin/bash
#SBATCH --mail-user=mcnabbc1@cardiff.ac.uk
#SBATCH --mail-type=END
#SBATCH --job-name=SW2_SWIhdbet
#SBATCH --partition=cubric-v100
#SBATCH --gpus=2
#SBATCH -o /cubric/collab/599_hub/sbatch_reports/SW2_SWIhdbet_%j.out
#SBATCH -e /cubric/collab/599_hub/sbatch_reports/SW2_SWIhdbet_%j.err

#change gitpath to the location of this repository
gitpath=/home/sapcm15/gitlab/brainandgenomicshub/SWI_SEPIA

export PATH=$PATH:${gitpath}

#Define the lines of the subject list that you want to work between - in this example, I read lines 1-3 of the subject list and assigned them to subs. Do not remove the 'p' after the second number.
subs=$( sed -n '1,3p' ${gitpath}/subject_list.txt )

#set paths
bids_dir=/cubric/collab/599_hub/hub_data
swi_dir=${bids_dir}/derivatives/SWI_SEPIA/preprocessed
hdbet_dir=${bids_dir}/derivatives/hdbet/preprocessed

#make a directory for the hdbet folder and delete anything that already exists in that folder (if the folder had been used for a previous command)
echo "Creating and/or deleting hd-bet folder in derivatives dir"
mkdir -p ${hdbet_dir}/head
if [ -d ${hdbet_dir}/head ]; then
    echo "deleting old head data"
    rm ${hdbet_dir}/head/*
fi

echo "copying data into brain extraction folder"
for sub in ${subs}; do
    cp ${bids_dir}/${sub}/ses-01/swi/${sub}_ses-01_echo-1_part-mag_GRE.nii.gz ${hdbet_dir}/head/${sub}_ses-01_part-mag_GRE.nii.gz
done

echo "Performing brain extraction using HD-BET"
hd-bet -i ${hdbet_dir}/head -o ${hdbet_dir}/brain

echo "copying brain extracted data back into SWI folder"
for sub in ${subs}; do
    cp ${hdbet_dir}/brain/${sub}_ses-01_part-mag_GRE_mask.nii.gz ${swi_dir}/${sub}/${sub}_ses-01_mask.nii.gz
done

