# Susceptibility weighted imaging pipeline for BSPRINT study
## Carolyn McNabb, 2025

### This pipeline uses the [SEPIA](https://github.com/kschan0214/sepia/releases) Toolbox. Documentation for this toolbox can be found [here](https://sepia-documentation.readthedocs.io/en/latest/getting_started/Installation.html)
Note, this toolbox relies of multiple other toolboxes to be installed first. For the Brain and Genomics Hub project, this has already been done and these are stored in `/cubric/collab/599_hub/software` along with the SEPIA toolbox.

## File mapping for reference
The UK biobank sequence was used to acquire these data and produces 5 files, 2 magnitude and 3 phase images. Data include files with coils combined and uncombined, as well as a normalised magnitude image, which we will use for our analysis.
**Note this is not needed for the analysis but is here for reference if anyone ever needs it**
```
014_scans_SWI_3mm_Updated_v1.1_20250217124620_c24_e1.nii.gz --> Magnitude images per coil (echo 1) --> MAG_TE1
014_scans_SWI_3mm_Updated_v1.1_20250217124620_c29_e2.nii.gz --> Magnitude images per coil (echo 2) --> MAG_TE2
015_scans_SWI_3mm_Updated_v1.1_20250217124620_e1.nii.gz --> Total magnitude image (echo 1) --> SWI_TOTAL_MAG_notNorm
015_scans_SWI_3mm_Updated_v1.1_20250217124620_e2.nii.gz --> Total magnitude image (echo 2) --> SWI_TOTAL_MAG_notNorm_TE2
016_scans_SWI_3mm_Updated_v1.1_20250217124620_e1.nii.gz --> Total magnitude image (normalised) (echo 1) --> SWI_TOTAL_MAG
016_scans_SWI_3mm_Updated_v1.1_20250217124620_e2.nii.gz --> Total magnitude image (normalised) (echo 2) --> SWI_TOTAL_MAG_TE2
017_scans_SWI_3mm_Updated_v1.1_20250217124620_c1_e2_ph.nii.gz --> Phase images per coil (echo 1) --> PHA_TE1
017_scans_SWI_3mm_Updated_v1.1_20250217124620_c23_e1_ph.nii.gz --> Phase images per coil (echo 2) --> PHA_TE2
018_scans_SWI_3mm_Updated_v1.1_20250217124620_e1_ph.nii.gz --> Total phase image (echo 1) --> SWI_TOTAL_PHA
018_scans_SWI_3mm_Updated_v1.1_20250217124620_e2_ph.nii.gz --> Total phase image (echo 1) --> SWI_TOTAL_PHA_TE2
```
For the analysis in SEPIA, we will use the normalised total magnitude data and the total phase data. 

## Before you start
To execute the batch scripts in the gitlab repository, you will need to change the permissions. To do this, open a linux terminal and type:
```
/path/to/this/repository
export PATH=$PATH:.
chmod u+x batch*.sh
```

## Subject list
Next, create a subject list, including a separate line for each subject in the BSPRINT study. In the linux terminal, type:
```
cd /cubric/collab/599_hub/hub_data
ls -d sub* >> /path/to/this/repository/subject_list.txt
```

## Data preparation
SEPIA likes the data to be in 4D format, with the two echoes included in the same file. We will create these manually and store them in the `/cubric/collab/599_hub/hub_data/derivatives/SWI_SEPIA/preprocessed` directory. Each subject will have their own folder within this directory. 

Before running this step, open `0.0_merge_echoes_SLURM.sh` and make sure all paths are correct and the report is being sent to your own email address. You should also check that paths in `batch_merge_echoes.sh`. **Note that this is a necessary step for ALL scripts in this repository but I will only mention it here.**

To run this step, in the linux terminal, type:
```
/path/to/this/repository
sbatch 0.0_merge_echoes_SLURM.sh
```
To check on the progress of your SLURM script, in the terminal, type:
```
squeue -u yourusername
```

## Brain extraction
Brain extraction is performed using [HD-BET](https://github.com/MIC-DKFZ/HD-BET) because it does a really good job and is likely better than the built-in brain extraction (FSL's bet) in the SEPIA toolbox.

To run the brain extraction, in the terminal, type: 
```
sbatch 0.1_hd-bet_SLURM.sh
```

## Running SEPIA
SEPIA runs in MATLAB. In order to get it to run, I had to add the paths to all folders and subfolders in the software folder.

In the MATLAB terminal, type:
```
addpath(genpath('/cubric/collab/599_hub/software/'))
sepia
```

I have copied the config file to the gitlab repo for batch scripting but there is more refinement needed first as the maps look okay but not wonderful. I think this is the phase unwrapping or another part of the preprocessing. Maybe some experimentation is needed.



